@@ -3,10 +3,10 @@ package CPAN;
 # If you want to inherit from CPAN, just change the constructor
 use vars qw{$META $Signal $End};
 
-$VERSION = '0.30a';
+$VERSION = '0.31a';
 
-# $Id: CPAN.pm,v 1.49 1996/09/17 21:43:39 k Exp $
-my $version = substr q$Revision: 1.49 $, 10;
+# $Id: CPAN.pm,v 1.51 1996/09/20 10:33:30 k Exp $
+my $version = substr q$Revision: 1.51 $, 10;
 
 BEGIN {require 5.002;}
 use Term::ReadLine;
@@ -98,38 +98,64 @@ sub checklock {
 	my $fh = IO::File->new($lockfile);
 	my $other = <$fh>;
 	$fh->close;
-	undef $fh;
-	chomp $other;
-	return if $$==$other; # should never happen
-	print qq{There seems to be running another CPAN process ($other). Trying to contact...\n};
-	if (kill 0, $other) {
-	    Carp::croak qq{Other job is running.\n}.
-		qq{You may want to kill it and delete the lockfile, maybe. On UNIX try:\n}.
-		qq{    kill $other\n}.
-		qq{    rm $lockfile\n};
-	} elsif (-w $lockfile) {
-	    my($ans)=
-		ExtUtils::MakeMaker::prompt
-		    (qq{Other job not responding. Shall I overwrite the lockfile? (Y/N)},"y");
-	    print("Ok, bye\n"), exit unless $ans =~ /^y/i;
-	} else {
-	    Carp::croak(
-			qq{Lockfile $lockfile not writeable by you. Cannot proceed.\n}.
-			qq{    On UNIX try:\n}.
+	if (defined $other && $other) {
+	    chomp $other;
+	    return if $$==$other; # should never happen
+	    print qq{There seems to be running another CPAN process ($other). Trying to contact...\n};
+	    if (kill 0, $other) {
+		Carp::croak qq{Other job is running.\n}.
+		    qq{You may want to kill it and delete the lockfile, maybe. On UNIX try:\n}.
 			qq{    kill $other\n}.
-			qq{    rm $lockfile\n}
-		       );
+			    qq{    rm $lockfile\n};
+	    } elsif (-w $lockfile) {
+		my($ans)=
+		    ExtUtils::MakeMaker::prompt
+			(qq{Other job not responding. Shall I overwrite the lockfile? (Y/N)},"y");
+		print("Ok, bye\n"), exit unless $ans =~ /^y/i;
+	    } else {
+		Carp::croak(
+			    qq{Lockfile $lockfile not writeable by you. Cannot proceed.\n}.
+			    qq{    On UNIX try:\n}.
+			    qq{    kill $other\n}.
+			    qq{    rm $lockfile\n}
+			   );
+	    }
 	}
     }
     File::Path::mkpath($CPAN::Config->{cpan_home});
-    my $fh = IO::File->new(">$lockfile") or Carp::croak "Could not open >$lockfile: $!";
+    my $fh;
+    unless ($fh = IO::File->new(">$lockfile")) {
+	if ($! =~ /Permission/) {
+	    my $incc = $INC{'CPAN/Config.pm'};
+	    my $myincc = MY->catfile($ENV{HOME},'.cpan','CPAN','MyConfig.pm');
+	    print qq{
+
+Your configuration suggests that CPAN.pm should use a working
+directory of
+    $CPAN::Config->{cpan_home}
+Unfortunately we could not create the lock file
+    $lockfile
+due to permission problems.
+
+Please make sure that the configuration variable
+    \$CPAN::Config->{cpan_home}
+points to a directory where you can write a .lock file. You can set
+this variable in either
+    $incc
+or
+    $myincc
+
+};
+	}
+	Carp::croak "Could not open >$lockfile: $!";
+    }
     print $fh $$, "\n";
     $self->{LOCK} = $lockfile;
     $fh->close;
     $SIG{'TERM'} = sub { &cleanup; die "Got SIGTERM, leaving"; };
     $SIG{'INT'} = sub { &cleanup, die "Got a second SIGINT" if $Signal; $Signal = 1; };
     $SIG{'__DIE__'} = \&cleanup;
-    print STDERR "Signal handler set.\n";
+    print STDERR "Signal handler set.\n" unless $CPAN::Config->{'inhibit-startup-message'};
 }
 
 sub DESTROY {
@@ -222,7 +248,7 @@ sub shell {
 cpan shell -- CPAN exploration and modules installation (v$CPAN::VERSION)
 Readline support $rl_avail
 
-};
+} unless $CPAN::Config->{'inhibit-startup-message'} ;
     while () {
 	if ($suppress_readline) {
 	    print $prompt;
@@ -962,7 +988,7 @@ sub get {
 	my($makefilepl) = $CPAN::META->catfile($packagedir,"Makefile.PL");
 	unless (-f $makefilepl) {
 	    my $fh = IO::File->new(">$makefilepl") or Carp::croak("Could not open >$makefilepl");
-	    my $cf = $self->called_for;
+	    my $cf = $self->called_for || "unknown";
 	    $fh->print(qq{
 # This Makefile.PL has been autogenerated by the module CPAN.pm
 # Autogenerated on: }.scalar localtime().qq{
